import setuptools
import pingmeen

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name                          = "pingmeen", 
    version                       = pingmeen.__version__,
    author                        = "Nikita M. Minaev",
    author_email                  = "nikita.minaev1995@gmail.com",
    description                   = "Notifications from your Python code",
    long_description              = long_description,
    long_description_content_type = "text/markdown",
    url                           = "",
    packages                      = setuptools.find_packages(),
    classifiers                   = [
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires               = '>=3.6',
)




import requests

class InvalidTokenError(Exception):
    def __init__(self, token):
        self.token = token
    
class Pingmeen:
    def __init__(self, token):
        self.token = token
        response = self.__server_query('validate_token')
        if response != 'true':
            print('"' + self.token + '" is not valid token. You can get new valid token by sending message to Pingmeen bot in Telegram ( https://t.me/PingmeenBot )')
            raise InvalidTokenError(self.token)
        
    def finish(self):
        self.__server_query('send_message')
        
    def __server_query(self, method):
        url = 'http://2kolobka.pro/nikita/pingmeen/'
        return requests.get(url + method + '.php?token=' + self.token).text